/*
  Java gfx-test framework

   Copyright (C) 2012, 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.VARIOUS)
@Zoom(1)
public class BitBltBufferedImageOp extends GfxTest
{
    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image containing horizontal stripes pattern
     * with type TYPE_3BYTE_BGR
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalStripesTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalStripesTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalColorStripesTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalColorStripesTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalColorStripesTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltBWDotsTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltColorDotsTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGrayscaleGradientTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGrayscaleGradientTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalRedGradientTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientType3ByteBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalRedGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalGreenGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalGreenGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalBlueGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalBlueGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalCyanGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalCyanGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalMagentaGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalMagentaGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalYellowGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientType3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientType4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltVerticalYellowGradientTypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture1TypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture2TypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture3TypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture4TypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeByteGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeIntBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeIntRGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeIntARGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeUshort555RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeUshort565RGB(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture5TypeUshortGray(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6Type3ByteBGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6Type4ByteABGR(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6Type4ByteABGR_Pre(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeByteBinary(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeByteIndexed(TestImage image, Graphics2D graphics2d, BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltRGBTexture6TypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltBufferedImageOp().runTestSuite(args);
    }
    
}
